==> okteta-17.04.1.tar.xz: okteta-17.04.1/kasten/core/document/bytearraydocumentfactory.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2006 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYDOCUMENTFACTORY_H
#define BYTEARRAYDOCUMENTFACTORY_H

// lib
#include <kasten/okteta/oktetakastencore_export.h>
// Kasten core
#include <kasten/abstractdocumentfactory.h>


namespace Kasten
{

class OKTETAKASTENCORE_EXPORT ByteArrayDocumentFactory : public AbstractDocumentFactory
{
    Q_OBJECT

  public: // AbstractDocumentFactory API
    virtual bool canCreateFromData( const QMimeData* mimeData );

    virtual AbstractDocument* create();
    virtual AbstractDocument* createFromData( const QMimeData* mimeData, bool setModified );
};

}

#endif

==> okteta-17.12.0.tar.xz: okteta-17.12.0/kasten/core/document/bytearraydocumentfactory.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2006 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYDOCUMENTFACTORY_H
#define BYTEARRAYDOCUMENTFACTORY_H

// lib
#include <kasten/okteta/oktetakastencore_export.h>
// Kasten core
#include <kasten/abstractdocumentfactory.h>


namespace Kasten
{

class OKTETAKASTENCORE_EXPORT ByteArrayDocumentFactory : public AbstractDocumentFactory
{
    Q_OBJECT

  public: // AbstractDocumentFactory API
    bool canCreateFromData( const QMimeData* mimeData ) override;

    AbstractDocument* create() override;
    AbstractDocument* createFromData( const QMimeData* mimeData, bool setModified ) override;
};

}

#endif
